@@ -43,7 +43,7 @@ impl Analyzer for BiomeAnalyzer {
     }
 
     fn build_report(&mut self) -> Result<Report> {
-        build_report(&self.lines)
+        Ok(build_report(&self.lines))
     }
 }
 
@@ -87,7 +87,7 @@ fn recognize_location_code(tline: &TLine) -> Option<LocationCode<'_>> {
 }
 
 /// Build a report from the output of biome
-pub fn build_report(cmd_lines: &[CommandOutputLine]) -> anyhow::Result<Report> {
+pub fn build_report(cmd_lines: &[CommandOutputLine]) -> Report {
     let mut items = ItemAccumulator::default();
     let mut last_is_blank = true;
     for cmd_line in cmd_lines {
@@ -112,5 +112,5 @@ pub fn build_report(cmd_lines: &[CommandOutputLine]) -> anyhow::Result<Report> {
             last_is_blank = is_blank;
         }
     }
-    Ok(items.report())
+    items.report()
 }
