@@ -96,7 +96,7 @@ impl NextestLineAnalyzer {
     ///
     /// with stderr maybe replaced by stdout or output
     ///
-    /// This supports nextest 0.9.95+ (see https://github.com/Canop/bacon/issues/350)
+    /// This supports nextest 0.9.95+ (see <https://github.com/Canop/bacon/issues/350>)
     fn stdx_section_key_v3(
         &self,
         content: &TLine,
@@ -187,7 +187,7 @@ fn is_location_v3(content: &TLine) -> bool {
         return false;
     }
     regex_is_match!(
-        r#"^\s*thread '.+' panicked at [^:\s'"]+:\d+:\d+:$"#,
+        r#"^\s*thread '.+'( \(\d+\))? panicked at [^:\s'"]+:\d+:\d+:$"#,
         &ts.raw
     )
 }
