@@ -43,18 +43,18 @@ impl Analyzer for RuffAnalyzer {
     }
 
     fn build_report(&mut self) -> Result<Report> {
-        build_report(&self.lines)
+        Ok(build_report(&self.lines))
     }
 }
 
-fn recognize_line(tline: &TLine) -> RuffLine {
+fn recognize_line(tline: &TLine) -> RuffLine<'_> {
     if let Some(lt) = recognize_location_message(tline) {
         return RuffLine::LocationTitle(lt);
     }
     RuffLine::Other
 }
 
-fn recognize_location_message(tline: &TLine) -> Option<LocationTitle> {
+fn recognize_location_message(tline: &TLine) -> Option<LocationTitle<'_>> {
     let tstrings = &tline.strings;
     if tstrings.len() < 8 {
         return None;
@@ -78,7 +78,7 @@ fn recognize_location_message(tline: &TLine) -> Option<LocationTitle> {
 }
 
 /// Build a report from the output of biome
-pub fn build_report(cmd_lines: &[CommandOutputLine]) -> anyhow::Result<Report> {
+pub fn build_report(cmd_lines: &[CommandOutputLine]) -> Report {
     let mut items = ItemAccumulator::default();
     let mut last_is_blank = true;
     let mut i = 0;
@@ -98,7 +98,7 @@ pub fn build_report(cmd_lines: &[CommandOutputLine]) -> anyhow::Result<Report> {
             items.push_error_title(burp::error_line_ts(message));
             items.push_line(
                 LineType::Location,
-                burp::location_line(format!("{}:{}:{}", path, line, column)),
+                burp::location_line(format!("{path}:{line}:{column}")),
             );
             last_is_blank = false;
         } else {
@@ -109,5 +109,5 @@ pub fn build_report(cmd_lines: &[CommandOutputLine]) -> anyhow::Result<Report> {
             last_is_blank = is_blank;
         }
     }
-    Ok(items.report())
+    items.report()
 }
