@@ -1,10 +1,10 @@
 use crate::*;
 
-/// A wrapped cmd_output, only valid for the cmd_output it was computed for,
+/// A wrapped cmd_output, only valid for the `cmd_output` it was computed for,
 /// contains references to the start and end of lines wrapped for a
 /// given width
 pub struct WrappedCommandOutput {
-    pub sub_lines: Vec<SubLine>,
+    pub sub_lines: Vec<Line>,
 
     /// in order to allow partial wrapping, and assuming the wrapped part
     /// didn't change, we store the count of lines which were wrapped so
@@ -13,7 +13,7 @@ pub struct WrappedCommandOutput {
 }
 
 impl WrappedCommandOutput {
-    /// compute a new wrapped cmd_output for a width and cmd_output.
+    /// compute a new wrapped `cmd_output` for a `width` and `cmd_output`.
     ///
     /// width is the total area width, including the scrollbar.
     pub fn new(
@@ -34,11 +34,8 @@ impl WrappedCommandOutput {
         cmd_output: &CommandOutput,
         width: u16,
     ) {
-        let mut new_lines = wrap(&cmd_output.lines[self.wrapped_lines_count..], width);
-        for mut line in new_lines.drain(..) {
-            line.line_idx += self.wrapped_lines_count;
-            self.sub_lines.push(line);
-        }
+        self.sub_lines
+            .extend(wrap(&cmd_output.lines[self.wrapped_lines_count..], width));
         self.wrapped_lines_count = cmd_output.lines.len();
     }
 }
