@@ -11,7 +11,9 @@ pub const CSI_GREEN: &str = "\u{1b}[32m";
 
 pub const CSI_RED: &str = "\u{1b}[31m";
 pub const CSI_BOLD_RED: &str = "\u{1b}[1m\u{1b}[38;5;9m";
+pub const CSI_BOLD_4BIT_RED: &str = "\u{1b}[1m\u{1b}[91m";
 pub const CSI_BOLD_ORANGE: &str = "\u{1b}[1m\u{1b}[38;5;208m";
+pub const CSI_BOLD_GREEN: &str = "\u{1b}[1m\u{1b}[38;5;34m";
 
 /// Used for "Blocking"
 pub const CSI_BLUE: &str = "\u{1b}[1m\u{1b}[36m";
@@ -25,6 +27,7 @@ pub const CSI_BOLD_YELLOW: &str = "\u{1b}[1m\u{1b}[33m";
 pub const CSI_BOLD_BLUE: &str = "\u{1b}[1m\u{1b}[38;5;14m";
 #[cfg(not(windows))]
 pub const CSI_BOLD_BLUE: &str = "\u{1b}[1m\u{1b}[38;5;12m";
+pub const CSI_BOLD_4BIT_BLUE: &str = "\u{1b}[1m\u{1b}[94m";
 
 #[cfg(windows)]
 pub const CSI_BOLD_4BIT_YELLOW: &str = "\u{1b}[1m\u{1b}[33m";
@@ -53,9 +56,9 @@ pub fn draw(
     raw: &str,
 ) -> Result<()> {
     if csi.is_empty() {
-        write!(w, "{}", raw)?;
+        write!(w, "{raw}")?;
     } else {
-        write!(w, "{}{}{}", csi, raw, CSI_RESET,)?;
+        write!(w, "{csi}{raw}{CSI_RESET}")?;
     }
     Ok(())
 }
@@ -63,5 +66,5 @@ pub fn csi(
     fg: u8,
     bg: u8,
 ) -> String {
-    format!("\u{1b}[1m\u{1b}[38;5;{}m\u{1b}[48;5;{}m", fg, bg)
+    format!("\u{1b}[1m\u{1b}[38;5;{fg}m\u{1b}[48;5;{bg}m")
 }
