@@ -3,10 +3,13 @@ mod app_state;
 mod dialog;
 mod drawing;
 mod focus_file;
+mod md;
 mod menu;
 mod messages;
+mod mission_state;
 mod scroll;
 mod search_state;
+mod show_item;
 mod wrap;
 
 pub use {
@@ -14,9 +17,12 @@ pub use {
     dialog::*,
     drawing::*,
     focus_file::*,
+    md::*,
     menu::*,
     messages::*,
+    mission_state::*,
     scroll::*,
     search_state::*,
+    show_item::*,
     wrap::*,
 };
