@@ -1,7 +1,7 @@
 # This script is dedicated to the official documentation site at https://dystroy.org/bacon
 
 # build the documentation site
-mkdocs build
+ddoc
 
 # copy the site to the deployement stage
 cp -r site/* ~/dev/www/dystroy/bacon/
